<?php
/**
 * Plugin Name: Export Customers from Woo to CSV
 * Plugin URI: https://amicatek.com/export-customers-from-woocommerce-to-csv/
 * Description: Extract customers from WooCommerce and export to CSV
 * Version: 1.0
 * Author: Amicatek
 * Author URI: https://amicatek.com
 */

// On installation, verify if WooCommerce is active
register_activation_hook( __FILE__, 'amk_woo_export_customers_activation' );

function amk_woo_export_customers_activation() {
    if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
        wp_die( 'This plugin requires WooCommerce to be installed and active.' );
    }
}

// Add a new menu item under Tools, but only shows to administrators:
add_action( 'admin_menu', 'amk_woo_export_customers' );

function amk_woo_export_customers() {
    add_management_page( 'Export Customers', 'Export Customers', 'manage_options', 'amk-woo-export-customers', 'amk_woo_export_customers_page' );
}

// Display the admin page
function amk_woo_export_customers_page() {
    echo '<div class="wrap">';
    echo '<h1>Export Customers</h1>';
    echo '<p>Export customers from WooCommerce and export to CSV</p>';
    echo '<p><a href="' . admin_url( 'tools.php?page=amk-woo-export-customers&export=1' ) . '" class="button button-primary">Export</a></p>';
    echo '</div>';
}

// Export customers to CSV
// Fields to export: Name, Surname, Email, Address, City, State, Zip, Country, Phone, Date Registered
// No limitaion on the number of customers to export
add_action( 'admin_init', 'amk_woo_export_customers_export' );

function amk_woo_export_customers_export() {
    if ( isset( $_GET['export'] ) && $_GET['export'] == 1 ) {
        $args = array(
            'role' => 'customer',
            'orderby' => 'registered',
            'order' => 'ASC',
            'fields' => array( 'ID', 'user_email', 'user_registered' ),
        );
        $customers = get_users( $args );
        $filename = 'customers-' . date( 'Y-m-d' ) . '.csv';
        $fp = fopen( 'php://output', 'w' );
        header( 'Content-type: application/csv' );
        header( 'Content-Disposition: attachment; filename=' . $filename );
        fputcsv( $fp, array( 'Name', 'Surname', 'Email', 'Address', 'City', 'State', 'Zip', 'Country', 'Phone', 'Date Registered' ) );
        foreach ( $customers as $customer ) {
            $user = get_userdata( $customer->ID );
            $user_meta = get_user_meta( $customer->ID );
            $address = get_user_meta( $customer->ID, 'shipping_address_1', true );
            $city = get_user_meta( $customer->ID, 'shipping_city', true );
            $state = get_user_meta( $customer->ID, 'shipping_state', true );
            $zip = get_user_meta( $customer->ID, 'shipping_postcode', true );
            $country = get_user_meta( $customer->ID, 'shipping_country', true );
            $phone = get_user_meta( $customer->ID, 'billing_phone', true );
            $name = $user->first_name;
            $surname = $user->last_name;
            $email = $user->user_email;
            $date_registered = $user->user_registered;
            fputcsv( $fp, array( $name, $surname, $email, $address, $city, $state, $zip, $country, $phone, $date_registered ) );
        }
        fclose( $fp );
        exit;
    }
}